#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-1KrfybzST4f8lFh7Wva0i9
key:                  gitit-0.15.1.2-1KrfybzST4f8lFh7Wva0i9
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  6feb318e6974eb5ca17610080cffe438
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-1KrfybzST4f8lFh7Wva0i9
depends:
    HStringTemplate-0.8.8-FhA5LRbR4w12LsQBcgZC8c
    HTTP-4000.4.1-LkUOcgMBczeF8qgODB2fxV
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU base-4.18.2.1
    base64-bytestring-1.2.1.0-7JruMLJLgBF2cqlGBjJEVX
    blaze-html-0.9.2.0-403xIyraa8W9X2ANuW0FPg bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-K8YCFRBCg6rC6YNwk2XnVn
    feed-1.3.2.1-8lE76z9YUb23TuRwGXVuyb filepath-1.4.300.1
    filestore-0.6.5.1-8O95lMoVBXZ9KhBhkEJw54 ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-3xVBhs6Jxop3MnN2vCZQTh
    hoauth2-2.14.0-4VsPTIUQFouIfDupfgemt9
    hslogger-1.3.2.0-E6C8jEKjAdBKKjE0uqQrQ7
    http-client-tls-0.3.6.4-9b928T241RZ4DZFzXPqqQg
    http-conduit-2.3.9.1-8twUbUhmT6XGKq0MgGFnSL
    json-0.10-DrUF4tVpfqqGjRollUnC4L mtl-2.3.1
    network-3.1.4.0-tP2o8Wry2b3nJpuPXPLoR
    network-bsd-2.8.1.0-Gj3ZmpB1wOf732LVQZJrt8
    network-uri-2.6.4.2-DXIr6FO81fkKKSx83uC4Cz
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG
    pandoc-3.6-6rRognLV5SyA8SD9g1uAnD
    pandoc-types-1.23.1-8LJiMtWugni7QOnHo0urnr parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-5FoUrrA3875KkJXWnCWBBA
    recaptcha-0.1.0.4-76F4TKwqaWNdPYzLFWw1h
    safe-0.3.21-Hishw766JFf9X5XLYDU9sV
    skylighting-0.14.4-6WMmDKWfExe4UPOzNDJFoh
    split-0.2.5-Bi3HfS9SciuGUuXE3PHa4h syb-0.7.3-AsxB5kY1s6JBFiF2Kn9gZL
    tagsoup-0.14.8-7VOpHkFP4Dh5DvT1rQTUnd
    temporary-1.3-A3KjuMYmCbV2j39Y1k6FK6 text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-1sH5ICXGcnt9c2aWdhwjAa
    url-2.1.3-7Kl4E3eXP9D927NfHGnLmQ
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    uuid-1.3.16.1-2FavIqrolec41NAkrHXRfw xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-6rYeqBf2P5OIeVRvkbWVxd
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-DnzIJnlgubqAiv00EdZGop
    zlib-0.7.1.0-B1SBPpvqNupJk2yVZpunOC

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

